@@ -113,7 +113,7 @@ class Reports(Client):
             })
             if file:
                 if isinstance(file, str):
-                    with open(file, "w") as text_file:
+                    with open(file, "w", encoding=character_code) as text_file:
                         text_file.write(document)
                 else:
                     file.write(document)
