@@ -1,7 +1,7 @@
 from enum import Enum
 
 
-class Granularity(Enum):
+class Granularity(str, Enum):
     HOUR = 'Hour'
     DAY = 'Day'
     WEEK = 'Week'
@@ -10,13 +10,13 @@ class Granularity(Enum):
     TOTAL = 'Total'
 
 
-class BuyerType(Enum):
+class BuyerType(str, Enum):
     B2B = 'B2B' # Business to business.
     B2C = 'B2C' # Business to customer.
     ALL = 'All' # Both of above
 
 
-class FirstDayOfWeek(Enum):
+class FirstDayOfWeek(str, Enum):
     MO = 'Monday'
     SU = 'Sunday'
 
